@@ -1,30 +1,24 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <algorithm>
-
-#include <guichan/exception.hpp>
-#include <guichan/graphics.hpp>
-#include <guichan/imagefont.hpp>
-
 #include "button.h"
 
 #include "../graphics.h"
@@ -34,6 +28,12 @@
 
 #include "../utils/dtor.h"
 
+#include <guichan/exception.hpp>
+#include <guichan/graphics.hpp>
+#include <guichan/font.hpp>
+
+#include <algorithm>
+
 int Button::mInstances = 0;
 
 enum{
@@ -52,10 +52,10 @@ struct ButtonData
 };
 
 static ButtonData const data[BUTTON_COUNT] = {
-    {"graphics/gui/button.png", 0, 0},
-    {"graphics/gui/buttonhi.png", 9, 4},
-    {"graphics/gui/buttonpress.png", 16, 19},
-    {"graphics/gui/button_disabled.png", 25, 23}
+    { "graphics/gui/button.png", 0, 0 },
+    { "graphics/gui/buttonhi.png", 9, 4 },
+    { "graphics/gui/buttonpress.png", 16, 19 },
+    { "graphics/gui/button_disabled.png", 25, 23 }
 };
 
 ImageRect Button::button[BUTTON_COUNT];
