@@ -1,21 +1,21 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
@@ -26,6 +26,7 @@
 
 #include "../guichanfwd.h"
 #include "../lockedarray.h"
+#include "../being.h"
 
 #include <guichan/actionlistener.hpp>
 
@@ -48,7 +49,7 @@ class CharSelectDialog : public Window, public gcn::ActionListener
          */
         CharSelectDialog(Network *network,
                          LockedArray<LocalPlayer*> *charInfo,
-                         unsigned char gender);
+                         Gender gender);
 
         void action(const gcn::ActionEvent &event);
 
@@ -76,7 +77,7 @@ class CharSelectDialog : public Window, public gcn::ActionListener
 
         PlayerBox *mPlayerBox;
 
-        unsigned char mGender;
+        Gender mGender;
         bool mCharSelected;
 
         /**
@@ -102,7 +103,7 @@ class CharCreateDialog : public Window, public gcn::ActionListener
          * Constructor.
          */
         CharCreateDialog(Window *parent, int slot, Network *network,
-                         unsigned char gender);
+                         Gender gender);
 
         /**
          * Destructor.
