@@ -1,21 +1,21 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
@@ -31,6 +31,8 @@
 
 #include "../net/network.h" // TODO this is just for iptostring, move that?
 
+#include "../utils/gettext.h"
+#include "../utils/strprintf.h"
 #include "../utils/tostring.h"
 
 extern SERVER_INFO **server_info;
@@ -47,15 +49,15 @@ class ServerListModel : public gcn::ListModel {
 };
 
 ServerSelectDialog::ServerSelectDialog(LoginData *loginData, int nextState):
-    Window("Select Server"),
+    Window(_("Select Server")),
     mLoginData(loginData),
     mNextState(nextState)
 {
     mServerListModel = new ServerListModel();
     mServerList = new ListBox(mServerListModel);
     ScrollArea *mScrollArea = new ScrollArea(mServerList);
-    mOkButton = new Button("OK", "ok", this);
-    Button *mCancelButton = new Button("Cancel", "cancel", this);
+    mOkButton = new Button(_("OK"), "ok", this);
+    Button *mCancelButton = new Button(_("Cancel"), "cancel", this);
 
     setContentSize(200, 100);
 
