@@ -1,116 +1,106 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include "item_amount.h"
 
 #include "button.h"
-#include "inttextbox.h"
+#include "inttextfield.h"
 #include "slider.h"
 #include "trade.h"
 
+#include "widgets/layout.h"
+
 #include "../item.h"
 #include "../localplayer.h"
 
+#include "../utils/gettext.h"
+
 ItemAmountWindow::ItemAmountWindow(int usage, Window *parent, Item *item):
-    Window("Select amount of items to drop.", true, parent),
+    Window("", true, parent),
     mItem(item)
 {
-    // New labels
-    mItemAmountTextBox = new IntTextBox(1);
+    const int maxRange = mItem->getQuantity();
 
-    // New buttons
-    Button *minusButton = new Button("-", "Minus", this);
-    Button *plusButton = new Button("+", "Plus", this);
-    Button *okButton = new Button("Okay", "Drop", this);
-    Button *cancelButton = new Button("Cancel", "Cancel", this);
-    mItemAmountSlide = new Slider(1.0, mItem->getQuantity());
+    // Integer field
+    mItemAmountTextField = new IntTextField(1);
+    mItemAmountTextField->setRange(1, maxRange);
+    mItemAmountTextField->setWidth(30);
+    mItemAmountTextField->setActionEventId("Dummy");
+    mItemAmountTextField->addActionListener(this);
 
-    mItemAmountTextBox->setRange(1, mItem->getQuantity());
-    mItemAmountSlide->setDimension(gcn::Rectangle(5, 120, 180, 10));
-
-    // Set button events Id
+    // Slider
+    mItemAmountSlide = new Slider(1.0, maxRange);
+    mItemAmountSlide->setHeight(10);
     mItemAmountSlide->setActionEventId("Slide");
-
-    // Set position
-    mItemAmountTextBox->setPosition(35, 10);
-    mItemAmountTextBox->setSize(24, 16);
-    plusButton->setPosition(60, 5);
-    minusButton->setPosition(10, 5);
-    mItemAmountSlide->setPosition(10, 35);
-    okButton->setPosition(10, 50);
-    cancelButton->setPosition(60, 50);
-
-    // Assemble
-    add(mItemAmountTextBox);
-    add(plusButton);
-    add(minusButton);
-    add(mItemAmountSlide);
-    add(okButton);
-    add(cancelButton);
-
     mItemAmountSlide->addActionListener(this);
 
+    // Buttons
+    Button *minusButton = new Button("-", "Minus", this);
+    minusButton->setSize(20, 20);
+    Button *plusButton = new Button("+", "Plus", this);
+    plusButton->setSize(20, 20);
+    Button *okButton = new Button(_("Ok"), "Drop", this);
+    Button *cancelButton = new Button(_("Cancel"), "Cancel", this);
+
+    // Set positions
+    place(0, 0, minusButton);
+    place(1, 0, mItemAmountTextField).setPadding(2);
+    place(2, 0, plusButton);
+    place(0, 1, mItemAmountSlide, 6);
+    place(4, 2, okButton);
+    place(5, 2, cancelButton);
+    reflowLayout(250, 0);
+
     resetAmount();
 
     switch (usage) {
         case AMOUNT_TRADE_ADD:
-            setCaption("Select amount of items to trade.");
+            setCaption(_("Select amount of items to trade."));
             okButton->setActionEventId("AddTrade");
             break;
         case AMOUNT_ITEM_DROP:
-            setCaption("Select amount of items to drop.");
+            setCaption(_("Select amount of items to drop."));
             okButton->setActionEventId("Drop");
             break;
         default:
             break;
     }
 
-    setContentSize(200, 80);
     setLocationRelativeTo(getParentWindow());
     setVisible(true);
 }
 
 void ItemAmountWindow::resetAmount()
 {
-    mItemAmountTextBox->setInt(1);
+    mItemAmountTextField->setValue(1);
 }
 
 void ItemAmountWindow::action(const gcn::ActionEvent &event)
 {
-    int amount = mItemAmountTextBox->getInt();
+    int amount = mItemAmountTextField->getValue();
 
     if (event.getId() == "Cancel")
     {
         scheduleDelete();
     }
-    else if (event.getId() == "Drop")
-    {
-        player_node->dropItem(mItem, mItemAmountTextBox->getInt());
-        scheduleDelete();
-    }
-    else if (event.getId() == "AddTrade")
-    {
-        tradeWindow->tradeItem(mItem, mItemAmountTextBox->getInt());
-        scheduleDelete();
-    }
     else if (event.getId() == "Plus")
     {
         amount++;
@@ -123,7 +113,16 @@ void ItemAmountWindow::action(const gcn::ActionEvent &event)
     {
         amount = static_cast<int>(mItemAmountSlide->getValue());
     }
-    mItemAmountTextBox->setInt(amount);
+    else if (event.getId() == "Drop")
+    {
+        player_node->dropItem(mItem, mItemAmountTextField->getValue());
+        scheduleDelete();
+    }
+    else if (event.getId() == "AddTrade")
+    {
+        tradeWindow->tradeItem(mItem, mItemAmountTextField->getValue());
+        scheduleDelete();
+    }
+    mItemAmountTextField->setValue(amount);
     mItemAmountSlide->setValue(amount);
 }
-
