@@ -1,26 +1,26 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef _TMW_ITEM_AMOUNT_WINDOW_H
-#define _TMW_ITEM_AMOUNT_WINDOW_H
+#ifndef ITEM_AMOUNT_WINDOW_H
+#define ITEM_AMOUNT_WINDOW_H
 
 #include <iosfwd>
 
@@ -30,7 +30,7 @@
 
 #include "../guichanfwd.h"
 
-class IntTextBox;
+class IntTextField;
 class Item;
 
 #define AMOUNT_TRADE_ADD 1
@@ -60,7 +60,7 @@ class ItemAmountWindow : public Window, public gcn::ActionListener
         void resetAmount();
 
     private:
-        IntTextBox *mItemAmountTextBox;   /**< Item amount caption. */
+        IntTextField *mItemAmountTextField;   /**< Item amount caption. */
         Item *mItem;
 
         /**
@@ -69,4 +69,4 @@ class ItemAmountWindow : public Window, public gcn::ActionListener
         gcn::Slider *mItemAmountSlide;
 };
 
-#endif /* _TMW_ITEM_AMOUNT_WINDOW_H */
+#endif /* ITEM_AMOUNT_WINDOW_H */
