@@ -1,26 +1,26 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef _TMW_MINISTATUS_H
-#define _TMW_MINISTATUS_H
+#ifndef MINISTATUS_H
+#define MINISTATUS_H
 
 #include <iosfwd>
 #include <vector>
@@ -46,12 +46,12 @@ class MiniStatusWindow : public Window
         MiniStatusWindow();
 
         /**
-         * Draw this window
+         * Draw this window.
          */
         void draw(gcn::Graphics *graphics);
 
         /**
-         * Sets one of the icons
+         * Sets one of the icons.
          */
         void setIcon(int index, AnimatedSprite *sprite);
 
@@ -61,7 +61,7 @@ class MiniStatusWindow : public Window
 
     private:
         /**
-         * Updates this dialog with values from player_node
+         * Updates this dialog with values from player_node.
          */
         void update();
 
@@ -71,9 +71,6 @@ class MiniStatusWindow : public Window
         ProgressBar *mHpBar;
         ProgressBar *mMpBar;
         ProgressBar *mXpBar;
-        gcn::Label *mHpLabel;
-        gcn::Label *mMpLabel;
-        gcn::Label *mXpLabel;
 
         std::vector<AnimatedSprite *> mIcons;
 };
