@@ -1,33 +1,33 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef _TMW_NPC_TEXT_H
-#define _TMW_NPC_TEXT_H
+#ifndef NPC_TEXT_H
+#define NPC_TEXT_H
 
 #include <iosfwd>
 #include <guichan/actionlistener.hpp>
 
 #include "window.h"
 
-class TextBox;
+class BrowserBox;
 
 /**
  * The npc text dialog.
@@ -45,7 +45,7 @@ class NpcTextDialog : public Window, public gcn::ActionListener
         NpcTextDialog();
 
         /**
-         * Called when resizing the window
+         * Called when resizing the window.
          *
          * @param event The calling event
          */
@@ -56,6 +56,11 @@ class NpcTextDialog : public Window, public gcn::ActionListener
          */
         void action(const gcn::ActionEvent &event);
 
+        /**
+         * Clears the text shown in the dialog.
+         */
+        void clearText();
+
         /**
          * Sets the text shows in the dialog.
          *
@@ -74,9 +79,7 @@ class NpcTextDialog : public Window, public gcn::ActionListener
     private:
         gcn::Button *okButton;
         gcn::ScrollArea *scrollArea;
-        TextBox *mTextBox;
-
-        std::string mText;
+        BrowserBox *mBrowserBox;
 };
 
-#endif // _TMW_NPC_TEXT_H
+#endif // NPC_TEXT_H
