@@ -1,21 +1,21 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
@@ -26,6 +26,8 @@
 #include "../resources/image.h"
 #include "../resources/resourcemanager.h"
 
+#include <guichan/font.hpp>
+
 ImageRect ProgressBar::mBorder;
 int ProgressBar::mInstances = 0;
 
@@ -88,32 +90,46 @@ void ProgressBar::logic()
     if (mBlueToGo < mBlue) mBlue--;
 }
 
-void
-ProgressBar::draw(gcn::Graphics *graphics)
+void ProgressBar::draw(gcn::Graphics *graphics)
 {
     static_cast<Graphics*>(graphics)->
         drawImageRect(0, 0, getWidth(), getHeight(), mBorder);
 
     // The bar
-    if (mProgress > 0)
-    {
+    if (mProgress > 0) {
         graphics->setColor(gcn::Color(mRed, mGreen, mBlue, 200));
         graphics->fillRectangle(gcn::Rectangle(4, 4,
-                    (int)(mProgress * (getWidth() - 8)),
+                    (int) (mProgress * (getWidth() - 8)),
                     getHeight() - 8));
     }
+
+    // The label
+    if (!mText.empty()) {
+        gcn::Font *f = getFont();
+        const int textX = getWidth() / 2;
+        const int textY = (getHeight() - f->getHeight()) / 2;
+
+        graphics->setFont(f);
+
+        graphics->setColor(gcn::Color(0, 0, 0));
+        graphics->drawText(mText, textX + 1, textY, gcn::Graphics::CENTER);
+        graphics->drawText(mText, textX, textY - 1, gcn::Graphics::CENTER);
+        graphics->drawText(mText, textX, textY + 1, gcn::Graphics::CENTER);
+        graphics->drawText(mText, textX - 1, textY, gcn::Graphics::CENTER);
+
+        graphics->setColor(gcn::Color(255, 255, 255));
+        graphics->drawText(mText, textX, textY, gcn::Graphics::CENTER);
+    }
 }
 
-void
-ProgressBar::setProgress(float progress)
+void ProgressBar::setProgress(float progress)
 {
     if (progress < 0.0f) mProgress = 0.0;
     else if (progress > 1.0f) mProgress = 1.0;
     else mProgress = progress;
 }
 
-void
-ProgressBar::setColor(Uint8 red, Uint8 green, Uint8 blue)
+void ProgressBar::setColor(Uint8 red, Uint8 green, Uint8 blue)
 {
     mRedToGo = red;
     mGreenToGo = green;
