@@ -1,40 +1,42 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef _TMW_PROGRESSBAR_H
-#define _TMW_PROGRESSBAR_H
+#ifndef PROGRESSBAR_H
+#define PROGRESSBAR_H
 
 #include <guichan/widget.hpp>
 
 #include <SDL_types.h>
 
-class ImageRect;
+#include <string>
 
+class ImageRect;
 
 /**
  * A progress bar.
  *
  * \ingroup GUI
  */
-class ProgressBar : public gcn::Widget {
+class ProgressBar : public gcn::Widget
+{
     public:
         /**
          * Constructor, initializes the progress with the given value.
@@ -51,55 +53,60 @@ class ProgressBar : public gcn::Widget {
         /**
          * Performs progress bar logic (fading colors)
          */
-        void
-        logic();
+        void logic();
 
         /**
          * Draws the progress bar.
          */
-        void
-        draw(gcn::Graphics *graphics);
+        void draw(gcn::Graphics *graphics);
 
         /**
          * Sets the current progress.
          */
-        void
-        setProgress(float progress);
+        void setProgress(float progress);
 
         /**
          * Returns the current progress.
          */
-        float
-        getProgress() { return mProgress; }
+        float getProgress() const { return mProgress; }
 
         /**
          * Change the filling of the progress bar.
          */
-        void
-        setColor(Uint8, Uint8 green, Uint8 blue);
+        void setColor(Uint8, Uint8 green, Uint8 blue);
 
         /**
-         * Get The red value of color
+         * Returns the red value of color.
          */
-        Uint8
-        getRed() { return mRed; }
-
-         /**
-         * Get The red value of color
-         */
-        Uint8
-        getGreen() { return mGreen; }
+        Uint8 getRed() const { return mRed; }
 
         /**
-         * Get The red value of color
+         * Returns the red value of color.
          */
-        Uint8
-        getBlue() { return mBlue; }
+        Uint8 getGreen() const { return mGreen; }
+
+        /**
+         * Returns the red value of color.
+         */
+        Uint8 getBlue() const { return mBlue; }
+
+        /**
+         * Sets the text shown on the progress bar.
+         */
+        void setText(const std::string &text)
+        { mText = text; }
+
+        /**
+         * Returns the text shown on the progress bar.
+         */
+        const std::string &text() const
+        { return mText; }
 
     private:
         float mProgress;
         Uint8 mRed, mGreen, mBlue;
         Uint8 mRedToGo, mGreenToGo, mBlueToGo;
+        std::string mText;
 
         static ImageRect mBorder;
         static int mInstances;
