@@ -1,26 +1,26 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef _TMW_RADIOBUTTON_H
-#define _TMW_RADIOBUTTON_H
+#ifndef RADIOBUTTON_H
+#define RADIOBUTTON_H
 
 #include <guichan/widgets/radiobutton.hpp>
 
@@ -48,6 +48,12 @@ class RadioButton : public gcn::RadioButton {
          */
         void drawBox(gcn::Graphics* graphics);
 
+        /**
+         * Implementation of the draw methods.
+         * Thus, avoiding the rhomb around the radio button.
+         */
+        void draw(gcn::Graphics* graphics);
+
     private:
         static int instances;
         static Image *radioNormal;
@@ -56,4 +62,4 @@ class RadioButton : public gcn::RadioButton {
         static Image *radioDisabledChecked;
 };
 
-#endif /* _TMW_RADIOBUTTON_H */
+#endif /* RADIOBUTTON_H */
