@@ -1,21 +1,21 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
@@ -39,14 +39,30 @@
 #include "textfield.h"
 #include "ok_dialog.h"
 
-void
-WrongDataNoticeListener::setTarget(gcn::TextField *textField)
+#include "widgets/layout.h"
+
+#include "../utils/gettext.h"
+#include "../utils/strprintf.h"
+
+/**
+ * Listener used while dealing with wrong data. It is used to direct the focus
+ * to the field which contained wrong data when the Ok button was pressed on
+ * the error notice.
+ */
+class WrongDataNoticeListener : public gcn::ActionListener {
+    public:
+        void setTarget(gcn::TextField *textField);
+        void action(const gcn::ActionEvent &event);
+    private:
+        gcn::TextField *mTarget;
+};
+
+void WrongDataNoticeListener::setTarget(gcn::TextField *textField)
 {
     mTarget = textField;
 }
 
-void
-WrongDataNoticeListener::action(const gcn::ActionEvent &event)
+void WrongDataNoticeListener::action(const gcn::ActionEvent &event)
 {
     if (event.getId() == "ok")
     {
@@ -54,57 +70,41 @@ WrongDataNoticeListener::action(const gcn::ActionEvent &event)
     }
 }
 
+
 RegisterDialog::RegisterDialog(LoginData *loginData):
-    Window("Register"),
-    mWrongDataNoticeListener(new WrongDataNoticeListener()),
+    Window(_("Register")),
+    mWrongDataNoticeListener(new WrongDataNoticeListener),
     mLoginData(loginData)
 {
-    gcn::Label *userLabel = new gcn::Label("Name:");
-    gcn::Label *passwordLabel = new gcn::Label("Password:");
-    gcn::Label *confirmLabel = new gcn::Label("Confirm:");
-    gcn::Label *serverLabel = new gcn::Label("Server:");
+    gcn::Label *userLabel = new gcn::Label(_("Name:"));
+    gcn::Label *passwordLabel = new gcn::Label(_("Password:"));
+    gcn::Label *confirmLabel = new gcn::Label(_("Confirm:"));
+    gcn::Label *serverLabel = new gcn::Label(_("Server:"));
     mUserField = new TextField(loginData->username);
     mPasswordField = new PasswordField(loginData->password);
-    mConfirmField = new PasswordField();
+    mConfirmField = new PasswordField;
     mServerField = new TextField(loginData->hostname);
-    mMaleButton = new RadioButton("Male", "sex", true);
-    mFemaleButton = new RadioButton("Female", "sex", false);
-    mRegisterButton = new Button("Register", "register", this);
-    mCancelButton = new Button("Cancel", "cancel", this);
+    mMaleButton = new RadioButton(_("Male"), "sex", true);
+    mFemaleButton = new RadioButton(_("Female"), "sex", false);
+    mRegisterButton = new Button(_("Register"), "register", this);
+    mCancelButton = new Button(_("Cancel"), "cancel", this);
 
-    const int width = 220;
-    const int height = 150;
-    setContentSize(width, height);
-
-    mUserField->setPosition(65, 5);
-    mUserField->setWidth(width - 70);
-    mPasswordField->setPosition(
-            65, mUserField->getY() + mUserField->getHeight() + 7);
-    mPasswordField->setWidth(mUserField->getWidth());
-    mConfirmField->setPosition(
-            65, mPasswordField->getY() + mPasswordField->getHeight() + 7);
-    mConfirmField->setWidth(mUserField->getWidth());
-    mServerField->setPosition(
-            65, 23 + mConfirmField->getY() + mConfirmField->getHeight() + 7);
-    mServerField->setWidth(mUserField->getWidth());
-
-    userLabel->setPosition(5, mUserField->getY() + 1);
-    passwordLabel->setPosition(5, mPasswordField->getY() + 1);
-    confirmLabel->setPosition(5, mConfirmField->getY() + 1);
-    serverLabel->setPosition(5, mServerField->getY() + 1);
-
-    mMaleButton->setPosition(
-            70, mConfirmField->getY() + mConfirmField->getHeight() + 7);
-    mFemaleButton->setPosition(
-            70 + 10 + mMaleButton->getWidth(),
-            mMaleButton->getY());
-
-    mCancelButton->setPosition(
-            width - mCancelButton->getWidth() - 5,
-            height - mCancelButton->getHeight() - 5);
-    mRegisterButton->setPosition(
-            mCancelButton->getX() - mRegisterButton->getWidth() - 5,
-            height - mRegisterButton->getHeight() - 5);
+    ContainerPlacer place;
+    place = getPlacer(0, 0);
+    place(0, 0, userLabel);
+    place(0, 1, passwordLabel);
+    place(0, 2, confirmLabel);
+    place(1, 3, mMaleButton);
+    place(2, 3, mFemaleButton);
+    place(0, 4, serverLabel);
+    place(1, 0, mUserField, 3).setPadding(2);
+    place(1, 1, mPasswordField, 3).setPadding(2);
+    place(1, 2, mConfirmField, 3).setPadding(2);
+    place(1, 4, mServerField, 3).setPadding(2);
+    place = getPlacer(0, 2);
+    place(1, 0, mRegisterButton);
+    place(2, 0, mCancelButton);
+    reflowLayout(250, 0);
 
     mUserField->addKeyListener(this);
     mPasswordField->addKeyListener(this);
@@ -125,19 +125,6 @@ RegisterDialog::RegisterDialog(LoginData *loginData):
     mConfirmField->addActionListener(this);
     mServerField->addActionListener(this);
 
-    add(userLabel);
-    add(passwordLabel);
-    add(serverLabel);
-    add(confirmLabel);
-    add(mUserField);
-    add(mPasswordField);
-    add(mConfirmField);
-    add(mServerField);
-    add(mMaleButton);
-    add(mFemaleButton);
-    add(mRegisterButton);
-    add(mCancelButton);
-
     setLocationRelativeTo(getParent());
     setVisible(true);
     mUserField->requestFocus();
@@ -151,8 +138,7 @@ RegisterDialog::~RegisterDialog()
     delete mWrongDataNoticeListener;
 }
 
-void
-RegisterDialog::action(const gcn::ActionEvent &event)
+void RegisterDialog::action(const gcn::ActionEvent &event)
 {
     if (event.getId() == "cancel")
     {
@@ -163,45 +149,45 @@ RegisterDialog::action(const gcn::ActionEvent &event)
         const std::string user = mUserField->getText();
         logger->log("RegisterDialog::register Username is %s", user.c_str());
 
-        std::stringstream errorMsg;
+        std::string errorMsg;
         int error = 0;
 
         if (user.length() < LEN_MIN_USERNAME)
         {
             // Name too short
-            errorMsg << "The username needs to be at least "
-                     << LEN_MIN_USERNAME
-                     << " characters long.";
+            errorMsg = strprintf
+                (_("The username needs to be at least %d characters long."),
+                 LEN_MIN_USERNAME);
             error = 1;
         }
         else if (user.length() > LEN_MAX_USERNAME - 1 )
         {
             // Name too long
-            errorMsg << "The username needs to be less than "
-                     << LEN_MAX_USERNAME
-                     << " characters long.";
+            errorMsg = strprintf
+                (_("The username needs to be less than %d characters long."),
+                 LEN_MAX_USERNAME);
             error = 1;
         }
         else if (mPasswordField->getText().length() < LEN_MIN_PASSWORD)
         {
             // Pass too short
-            errorMsg << "The password needs to be at least "
-                     << LEN_MIN_PASSWORD
-                     << " characters long.";
+            errorMsg = strprintf
+                (_("The password needs to be at least %d characters long."),
+                 LEN_MIN_PASSWORD);
             error = 2;
         }
         else if (mPasswordField->getText().length() > LEN_MAX_PASSWORD - 1 )
         {
             // Pass too long
-            errorMsg << "The password needs to be less than "
-                     << LEN_MAX_PASSWORD
-                     << " characters long.";
+            errorMsg = strprintf
+                (_("The password needs to be less than %d characters long."),
+                 LEN_MAX_PASSWORD);
             error = 2;
         }
         else if (mPasswordField->getText() != mConfirmField->getText())
         {
             // Password does not match with the confirmation one
-            errorMsg << "Passwords do not match.";
+            errorMsg = _("Passwords do not match.");
             error = 2;
         }
 
@@ -220,8 +206,8 @@ RegisterDialog::action(const gcn::ActionEvent &event)
                 mWrongDataNoticeListener->setTarget(this->mPasswordField);
             }
 
-            OkDialog *mWrongRegisterNotice = new OkDialog("Error",
-                                                          errorMsg.str());
+            OkDialog *mWrongRegisterNotice =
+                new OkDialog(_("Error"), errorMsg);
             mWrongRegisterNotice->addActionListener(mWrongDataNoticeListener);
         }
         else
@@ -241,14 +227,12 @@ RegisterDialog::action(const gcn::ActionEvent &event)
     }
 }
 
-void
-RegisterDialog::keyPressed(gcn::KeyEvent &keyEvent)
+void RegisterDialog::keyPressed(gcn::KeyEvent &keyEvent)
 {
     mRegisterButton->setEnabled(canSubmit());
 }
 
-bool
-RegisterDialog::canSubmit()
+bool RegisterDialog::canSubmit() const
 {
     return !mUserField->getText().empty() &&
            !mPasswordField->getText().empty() &&
