@@ -1,26 +1,24 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <algorithm>
-
 #include "setup.h"
 
 #include "button.h"
@@ -29,9 +27,13 @@
 #include "setup_video.h"
 #include "setup_keyboard.h"
 #include "setup_players.h"
-#include "tabbedcontainer.h"
+
+#include "widgets/tabbedarea.h"
 
 #include "../utils/dtor.h"
+#include "../utils/gettext.h"
+
+#include <algorithm>
 #include <iostream>
 
 extern Window *statusWindow;
@@ -42,21 +44,22 @@ extern Window *equipmentWindow;
 extern Window *helpWindow;
 extern Window *skillDialog;
 extern Window *itemShortcutWindow;
+extern Window *tradeWindow;
 
 Setup::Setup():
-    Window("Setup")
+    Window(_("Setup"))
 {
     setCloseButton(true);
     int width = 310;
-    int height = 265;
+    int height = 310;
     setContentSize(width, height);
 
-    const char *buttonNames[] = {
-        "Apply", "Cancel", "Reset Windows", 0
+    static const char *buttonNames[] = {
+        N_("Apply"), N_("Cancel"), N_("Reset Windows"), 0
     };
     int x = width;
     for (const char **curBtn = buttonNames; *curBtn; ++curBtn) {
-        Button *btn = new Button(*curBtn, *curBtn, this);
+        Button *btn = new Button(gettext(*curBtn), *curBtn, this);
         x -= btn->getWidth() + 5;
         btn->setPosition(x, height - btn->getHeight() - 5);
         add(btn);
@@ -66,30 +69,29 @@ Setup::Setup():
             btn->setEnabled(statusWindow != NULL);
     }
 
-    TabbedContainer *panel = new TabbedContainer();
-    panel->setDimension(gcn::Rectangle(5, 5, width, height - 40));
-    panel->setOpaque(false);
+    TabbedArea *panel = new TabbedArea();
+    panel->setDimension(gcn::Rectangle(5, 5, width - 10, height - 40));
 
     SetupTab *tab;
 
     tab = new Setup_Video();
-    panel->addTab(tab, "Video");
+    panel->addTab(_("Video"), tab);
     mTabs.push_back(tab);
 
     tab = new Setup_Audio();
-    panel->addTab(tab, "Audio");
+    panel->addTab(_("Audio"), tab);
     mTabs.push_back(tab);
 
     tab = new Setup_Joystick();
-    panel->addTab(tab, "Joystick");
+    panel->addTab(_("Joystick"), tab);
     mTabs.push_back(tab);
 
     tab = new Setup_Keyboard();
-    panel->addTab(tab, "Keyboard");
+    panel->addTab(_("Keyboard"), tab);
     mTabs.push_back(tab);
 
     tab = new Setup_Players();
-    panel->addTab(tab, "Players");
+    panel->addTab(_("Players"), tab);
     mTabs.push_back(tab);
 
     add(panel);
@@ -129,5 +131,6 @@ void Setup::action(const gcn::ActionEvent &event)
         helpWindow->resetToDefaultSize();
         skillDialog->resetToDefaultSize();
         itemShortcutWindow->resetToDefaultSize();
+        tradeWindow->resetToDefaultSize();
     }
 }
