@@ -1,21 +1,21 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
@@ -29,12 +29,14 @@
 #include "windowcontainer.h"
 
 #include "../localplayer.h"
-
-#include "../utils/dtor.h"
-#include "../utils/xml.h"
 #include "../log.h"
 
-#define SKILLS_FILE "skills.xml"
+#include "../utils/dtor.h"
+#include "../utils/gettext.h"
+#include "../utils/strprintf.h"
+#include "../utils/xml.h"
+
+static const char *SKILLS_FILE = "skills.xml";
 
 struct SkillInfo {
     std::string name;
@@ -43,7 +45,7 @@ struct SkillInfo {
 
 std::vector<SkillInfo> skill_db;
 
-static void initSkillinfo(void);
+static void initSkillinfo();
 
 class SkillGuiTableModel : public StaticTableModel
 {
@@ -56,11 +58,9 @@ public:
         update();
     }
 
-    virtual int
-    getRows(void) { return mEntriesNr; }
+    virtual int getRows() { return mEntriesNr; }
 
-    virtual int
-    getColumnWidth(int index)
+    virtual int getColumnWidth(int index)
     {
         switch (index) {
         case 0:  return 160;
@@ -68,16 +68,17 @@ public:
         }
     }
 
-    virtual int
-    getRowHeight(void)
+    virtual int getRowHeight()
     {
         return 12;
     }
 
-    virtual void
-    update(void)
+    virtual void update()
     {
-        static const SkillInfo fakeSkillInfo = { "Mystery Skill", false };
+        static const SkillInfo fakeSkillInfo = {
+            _("Mystery Skill"),
+            false
+        };
 
         mEntriesNr = mDialog->getSkills().size();
         resize();
@@ -94,13 +95,13 @@ public:
                 info = &fakeSkillInfo;
 
             sprintf(tmp, "%c%s", info->modifiable? ' ' : '*', info->name.c_str());
-            gcn::Label *name_label = new gcn::Label(std::string(tmp));
+            gcn::Label *name_label = new gcn::Label(tmp);
 
             sprintf(tmp, "Lv:%i", skill->lv);
-            gcn::Label *lv_label = new gcn::Label(std::string(tmp));
+            gcn::Label *lv_label = new gcn::Label(tmp);
 
             sprintf(tmp, "Sp:%i", skill->sp);
-            gcn::Label *sp_label = new gcn::Label(std::string(tmp));
+            gcn::Label *sp_label = new gcn::Label(tmp);
 
             set(i, 0, name_label);
             set(i, 1, lv_label);
@@ -108,7 +109,6 @@ public:
         }
     }
 
-
 private:
     SkillDialog *mDialog;
     int mEntriesNr;
@@ -116,7 +116,7 @@ private:
 
 
 SkillDialog::SkillDialog():
-    Window("Skills")
+    Window(_("Skills"))
 {
     initSkillinfo();
     mTableModel = new SkillGuiTableModel(this);
@@ -129,9 +129,9 @@ SkillDialog::SkillDialog():
 
 //    mSkillListBox = new ListBox(this);
     ScrollArea *skillScrollArea = new ScrollArea(&mTable);
-    mPointsLabel = new gcn::Label("Skill Points:");
-    mIncButton = new Button("Up", "inc", this);
-    mUseButton = new Button("Use", "use", this);
+    mPointsLabel = new gcn::Label(strprintf(_("Skill points: %d"), 0));
+    mIncButton = new Button(_("Up"), "inc", this);
+    mUseButton = new Button(_("Use"), "use", this);
     mUseButton->setEnabled(false);
 
 //    mSkillListBox->setActionEventId("skill");
@@ -185,11 +185,8 @@ void SkillDialog::action(const gcn::ActionEvent &event)
 
 void SkillDialog::update()
 {
-    if (mPointsLabel != NULL) {
-        char tmp[128];
-        sprintf(tmp, "Skill points: %i", player_node->mSkillPoint);
-        mPointsLabel->setCaption(tmp);
-    }
+    mPointsLabel->setCaption(strprintf(_("Skill points: %d"),
+                                       player_node->mSkillPoint));
 
     int selectedSkill = mTable.getSelectedRow();
 
@@ -250,8 +247,7 @@ void SkillDialog::cleanList()
     mSkillList.clear();
 }
 
-static void
-initSkillinfo(void)
+static void initSkillinfo()
 {
     SkillInfo emptySkillInfo = { "", false };
 
@@ -260,8 +256,7 @@ initSkillinfo(void)
 
     if (!root || !xmlStrEqual(root->name, BAD_CAST "skills"))
     {
-        logger->log("Error loading skills file: "
-                    SKILLS_FILE);
+        logger->log("Error loading skills file: %s", SKILLS_FILE);
         skill_db.resize(2, emptySkillInfo);
         skill_db[1].name = "Basic";
         skill_db[1].modifiable = true;
