@@ -213,13 +213,14 @@ void setUpdatesDir()
  */
 void init_engine(const Options &options)
 {
-    homeDir = std::string(PHYSFS_getUserDir()) + "/.tmw";
+    if (homeDir.empty())
+        homeDir = std::string(PHYSFS_getUserDir()) + "/.tmw";
 #if defined WIN32
     if (!CreateDirectory(homeDir.c_str(), 0) &&
             GetLastError() != ERROR_ALREADY_EXISTS)
 #elif defined __APPLE__
     // Use Application Directory instead of .tmw
-    homeDir = std::string(PHYSFS_getUserDir()) + 
+    homeDir = std::string(PHYSFS_getUserDir()) +
         "/Library/Application Support/The Mana World";
     if ((mkdir(homeDir.c_str(), S_IRWXU | S_IRWXG | S_IROTH | S_IXOTH) != 0) &&
             (errno != EEXIST))
@@ -451,7 +452,8 @@ void printHelp()
         << "  -D --default    : Bypass the login process with default settings" << std::endl
         << "  -p --playername : Login with this player" << std::endl
         << "  -C --configfile : Configuration file to use" << std::endl
-        << "  -H --updatehost : Use this update host" << std::endl;
+        << "  -H --updatehost : Use this update host" << std::endl
+        << "  -S --homedir    : Directory to use as home directory" << std::endl;
 }
 
 void printVersion()
@@ -466,7 +468,7 @@ void printVersion()
 
 void parseOptions(int argc, char *argv[], Options &options)
 {
-    const char *optstring = "hvud:U:P:Dp:C:H:";
+    const char *optstring = "hvud:U:P:Dp:C:H:S:";
 
     const struct option long_options[] = {
         { "help",       no_argument,       0, 'h' },
@@ -479,6 +481,7 @@ void parseOptions(int argc, char *argv[], Options &options)
         { "playername", required_argument, 0, 'p' },
         { "configfile", required_argument, 0, 'C' },
         { "updatehost", required_argument, 0, 'H' },
+        { "homedir",    required_argument, 0, 'S' },
         { 0 }
     };
 
@@ -521,6 +524,9 @@ void parseOptions(int argc, char *argv[], Options &options)
             case 'H':
                 options.updateHost = optarg;
                 break;
+            case 'S':
+                homeDir = optarg;
+                break;
         }
     }
 }
@@ -672,9 +678,12 @@ int main(int argc, char *argv[])
 #if ENABLE_NLS
 #ifdef WIN32
         putenv(("LANG=" + std::string(_nl_locale_name_default())).c_str());
+        // mingw doesn't like LOCALEDIR to be defined for some reason
+        bindtextdomain("tmw", "translations/");
+#else
+        bindtextdomain("tmw", LOCALEDIR);
 #endif
         setlocale(LC_MESSAGES, "");
-        bindtextdomain("tmw", LOCALEDIR);
         bind_textdomain_codeset("tmw", "UTF-8");
         textdomain("tmw");
 #endif
