@@ -1,21 +1,21 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
@@ -141,7 +141,8 @@ void BeingHandler::handleMessage(MessageIn *msg)
             msg->readInt16();  // manner
             dstBeing->setStatusEffectBlock(32, msg->readInt16());  // opt3
             msg->readInt8();   // karma
-            dstBeing->setGender(1 - msg->readInt8());   // gender
+            dstBeing->setGender(
+                    (msg->readInt8() == 0) ? GENDER_FEMALE : GENDER_MALE);
 
             // Set these after the gender, as the sprites may be gender-specific
             dstBeing->setSprite(Being::BOTTOMCLOTHES_SPRITE, headBottom);
@@ -420,7 +421,8 @@ void BeingHandler::handleMessage(MessageIn *msg)
             msg->readInt16();  // manner
             dstBeing->setStatusEffectBlock(32, msg->readInt16());  // opt3
             msg->readInt8();   // karma
-            dstBeing->setGender(1 - msg->readInt8());   // gender
+            dstBeing->setGender(
+                    (msg->readInt8() == 0) ? GENDER_FEMALE : GENDER_MALE);
 
             // Set these after the gender, as the sprites may be gender-specific
             dstBeing->setSprite(Being::WEAPON_SPRITE, weapon);
