@@ -1,21 +1,21 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
@@ -45,7 +45,8 @@
 #include "resources/image.h"
 
 OpenGLGraphics::OpenGLGraphics():
-    mAlpha(false), mTexture(false), mColorAlpha(false)
+    mAlpha(false), mTexture(false), mColorAlpha(false),
+    mSync(false)
 {
 }
 
@@ -53,6 +54,11 @@ OpenGLGraphics::~OpenGLGraphics()
 {
 }
 
+void OpenGLGraphics::setSync(bool sync)
+{
+    mSync = sync;
+}
+
 bool OpenGLGraphics::setVideoMode(int w, int h, int bpp, bool fs, bool hwaccel)
 {
     logger->log("Setting video mode %dx%d %s",
@@ -74,8 +80,10 @@ bool OpenGLGraphics::setVideoMode(int w, int h, int bpp, bool fs, bool hwaccel)
     }
 
 #ifdef __APPLE__
-//    long VBL = 1;
-//    CGLSetParameter(CGLGetCurrentContext(), kCGLCPSwapInterval, &VBL);
+    if (mSync) {
+        const GLint VBL = 1;
+        CGLSetParameter(CGLGetCurrentContext(), kCGLCPSwapInterval, &VBL);
+    }
 #endif
 
     // Setup OpenGL
@@ -352,7 +360,7 @@ void OpenGLGraphics::setTexturingAndBlending(bool enable)
 
 void OpenGLGraphics::drawRectangle(const gcn::Rectangle& rect, bool filled)
 {
-    float offset = filled ? 0 : 0.5f;
+    const float offset = filled ? 0 : 0.5f;
 
     setTexturingAndBlending(false);
 
