@@ -1,26 +1,26 @@
 /*
  *  The Mana World
- *  Copyright 2007 The Mana World Development Team
+ *  Copyright (C) 2007  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef _TMW_DYE_H
-#define _TMW_DYE_H
+#ifndef DYE_H
+#define DYE_H
 
 #include <vector>
 
@@ -36,7 +36,7 @@ class Palette
          * The string is either a file name or a sequence of hexadecimal RGB
          * values separated by ',' and starting with '#'.
          */
-        Palette(std::string const &);
+        Palette(const std::string &);
 
         /**
          * Gets a pixel color depending on its intensity.
@@ -63,7 +63,7 @@ class Dye
          * The parts of string are separated by semi-colons. Each part starts
          * by an uppercase letter, followed by a colon and then a palette name.
          */
-        Dye(std::string const &);
+        Dye(const std::string &);
 
         /**
          * Destroys the associated palettes.
@@ -79,7 +79,7 @@ class Dye
          * Fills the blank in a dye placeholder with some palette names.
          */
         static void instantiate(std::string &target,
-                                std::string const &palettes);
+                                const std::string &palettes);
 
     private:
 
