@@ -1,26 +1,26 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef _TMW_ITEMINFO_H_
-#define _TMW_ITEMINFO_H_
+#ifndef ITEMINFO_H
+#define ITEMINFO_H
 
 #include <map>
 #include <string>
@@ -28,6 +28,8 @@
 
 #include "spritedef.h"
 
+#include "../being.h"
+
 enum EquipmentSoundEvent
 {
     EQUIP_EVENT_STRIKE,
@@ -91,10 +93,10 @@ class ItemInfo
         void setView(int view)
         { mView = view; }
 
-        void setSprite(const std::string &animationFile, int gender)
+        void setSprite(const std::string &animationFile, Gender gender)
         { mAnimationFiles[gender] = animationFile; }
 
-        const std::string& getSprite(int gender) const;
+        const std::string& getSprite(Gender gender) const;
 
         void setWeaponType(int);
 
