@@ -1,21 +1,21 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
@@ -195,6 +195,8 @@ Map *MapReader::readMap(const std::string &filename)
         logger->log("Error while parsing map file (%s)!", filename.c_str());
     }
 
+    if (map) map->setProperty("_filename", filename);
+
     return map;
 }
 
@@ -304,7 +306,8 @@ void MapReader::readProperties(xmlNodePtr node, Properties *props)
 static void setTile(Map *map, MapLayer *layer, int x, int y, int gid)
 {
     const Tileset * const set = map->getTilesetWithGid(gid);
-    if (layer) {
+    if (layer)
+    {
         // Set regular tile on a layer
         Image * const img = set ? set->get(gid - set->getFirstGid()) : 0;
         layer->setTile(x, y, img);
@@ -407,6 +410,12 @@ void MapReader::readLayer(xmlNodePtr node, Map *map)
 
                     setTile(map, layer, x, y, gid);
 
+                    TileAnimation* ani = map->getAnimationForGid(gid);
+                    if (ani)
+                    {
+                        ani->addAffectedTile(layer, x + y * w);
+                    }
+
                     x++;
                     if (x == w) {
                         x = 0; y++;
@@ -452,10 +461,12 @@ Tileset *MapReader::readTileset(xmlNodePtr node,
                                 const std::string &path,
                                 Map *map)
 {
+    Tileset *set = NULL;
+
     if (xmlHasProp(node, BAD_CAST "source"))
     {
         logger->log("Warning: External tilesets not supported yet.");
-        return NULL;
+        return set;
     }
 
     const int firstGid = XML::getProperty(node, "firstgid", 0);
@@ -464,34 +475,75 @@ Tileset *MapReader::readTileset(xmlNodePtr node,
 
     for_each_xml_child_node(childNode, node)
     {
-        if (!xmlStrEqual(childNode->name, BAD_CAST "image"))
-            continue;
-
-        const std::string source = XML::getProperty(childNode, "source", "");
-
-        if (!source.empty())
+        if (xmlStrEqual(childNode->name, BAD_CAST "image"))
         {
-            std::string sourceStr = source;
-            sourceStr.erase(0, 3);  // Remove "../"
+            const std::string source = XML::getProperty(childNode, "source", "");
 
-            ResourceManager *resman = ResourceManager::getInstance();
-            Image* tilebmp = resman->getImage(sourceStr);
-
-            if (tilebmp)
+            if (!source.empty())
             {
-                Tileset *set = new Tileset(tilebmp, tw, th, firstGid);
-                tilebmp->decRef();
-                return set;
-            }
-            else {
-                logger->log("Warning: Failed to load tileset (%s)",
-                        source.c_str());
+                std::string sourceStr = source;
+                sourceStr.erase(0, 3);  // Remove "../"
+
+                ResourceManager *resman = ResourceManager::getInstance();
+                Image* tilebmp = resman->getImage(sourceStr);
+
+                if (tilebmp)
+                {
+                    set = new Tileset(tilebmp, tw, th, firstGid);
+                    tilebmp->decRef();
+                }
+                else {
+                    logger->log("Warning: Failed to load tileset (%s)",
+                            source.c_str());
+                }
             }
         }
+        else if (xmlStrEqual(childNode->name, BAD_CAST "tile"))
+        {
+            for_each_xml_child_node(tileNode, childNode)
+            {
+                if (!xmlStrEqual(tileNode->name, BAD_CAST "properties")) continue;
 
-        // Only one image element expected
-        break;
+                int tileGID = firstGid + XML::getProperty(childNode, "id", 0);
+
+                // read tile properties to a map for simpler handling
+                std::map<std::string, int> tileProperties;
+                for_each_xml_child_node(propertyNode, tileNode)
+                {
+                    if (!xmlStrEqual(propertyNode->name, BAD_CAST "property")) continue;
+                    std::string name = XML::getProperty(propertyNode, "name", "");
+                    int value = XML::getProperty(propertyNode, "value", 0);
+                    tileProperties[name] = value;
+                    logger->log("Tile Prop of %d \"%s\" = \"%d\"", tileGID, name.c_str(), value);
+                }
+
+                // create animation
+                if (!set) continue;
+
+                Animation *ani = new Animation();
+                for (int i = 0; ;i++)
+                {
+                    std::map<std::string, int>::iterator iFrame, iDelay;
+                    iFrame = tileProperties.find("animation-frame" + toString(i));
+                    iDelay = tileProperties.find("animation-delay" + toString(i));
+                    if (iFrame != tileProperties.end() && iDelay != tileProperties.end())
+                    {
+                        ani->addFrame(set->get(iFrame->second), iDelay->second, 0, 0);
+                    } else {
+                        break;
+                    }
+                }
+
+                if (ani->getLength() > 0)
+                {
+                    map->addAnimation(tileGID, new TileAnimation(ani));
+                    logger->log("Animation length: %d", ani->getLength());
+                } else {
+                    delete ani;
+                }
+            }
+        }
     }
 
-    return NULL;
+    return set;
 }
