@@ -1,21 +1,21 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
@@ -215,7 +215,7 @@ std::string ResourceManager::getPath(const std::string &file)
     return path;
 }
 
-Resource *ResourceManager::get(std::string const &idPath, generator fun,
+Resource *ResourceManager::get(const std::string &idPath, generator fun,
                                void *data)
 {
     // Check if the id exists, and return the value if it does.
@@ -267,7 +267,7 @@ struct ResourceLoader
     }
 };
 
-Resource *ResourceManager::load(std::string const &path, loader fun)
+Resource *ResourceManager::load(const std::string &path, loader fun)
 {
     ResourceLoader l = { this, path, fun };
     return get(path, ResourceLoader::load, &l);
@@ -309,7 +309,7 @@ struct DyedImageLoader
     }
 };
 
-Image *ResourceManager::getImage(std::string const &idPath)
+Image *ResourceManager::getImage(const std::string &idPath)
 {
     DyedImageLoader l = { this, idPath };
     return static_cast<Image*>(get(idPath, DyedImageLoader::load, &l));
@@ -351,8 +351,7 @@ struct SpriteDefLoader
     }
 };
 
-SpriteDef *ResourceManager::getSprite
-    (std::string const &path, int variant)
+SpriteDef *ResourceManager::getSprite(const std::string &path, int variant)
 {
     SpriteDefLoader l = { path, variant };
     std::stringstream ss;
@@ -381,7 +380,8 @@ void ResourceManager::release(Resource *res)
 ResourceManager *ResourceManager::getInstance()
 {
     // Create a new instance if necessary.
-    if (instance == NULL) instance = new ResourceManager();
+    if (!instance)
+        instance = new ResourceManager();
     return instance;
 }
 
