@@ -1,26 +1,26 @@
 /*
  *  The Mana World
- *  Copyright 2008 The Mana World Development Team
+ *  Copyright (C) 2008  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef _TMW_TEXT_H
-#define _TMW_TEXT_H
+#ifndef TEXT_H
+#define TEXT_H
 
 #include "graphics.h"
 
@@ -37,8 +37,8 @@ class Text
          * Constructor creates a text object to display on the screen.
          */
         Text(const std::string &text, int x, int y,
-             gcn::Graphics::Alignment alignment, gcn::Font *font,
-             gcn::Color colour);
+             gcn::Graphics::Alignment alignment,
+             gcn::Color colour, bool isSpeech = false);
 
         /**
          * Destructor. The text is removed from the screen.
@@ -62,16 +62,20 @@ class Text
         int mHeight;           /**< The height of the text. */
         int mXOffset;          /**< The offset of mX from the desired x. */
         static int mInstances; /**< Instances of text. */
-        gcn::Font *mFont;      /**< The font used. */
         std::string mText;     /**< The text to display. */
         gcn::Color mColour;    /**< The colour of the text. */
+        bool mIsSpeech;        /**< Is this text a speech bubble? */
+
+    protected:
+        static ImageRect mBubble;   /**< Speech bubble graphic */
+        static Image *mBubbleArrow; /**< Speech bubble arrow graphic */
 };
 
 class FlashText : public Text
 {
     public:
         FlashText(const std::string &text, int x, int y,
-                  gcn::Graphics::Alignment alignment, gcn::Font *font,
+                  gcn::Graphics::Alignment alignment,
                   gcn::Color colour);
 
         /**
@@ -88,4 +92,4 @@ class FlashText : public Text
         int mTime;             /**< Time left for flashing. */
 };
 
-#endif // _TMW_TEXT_H
+#endif // TEXT_H
